==> pycleanarch-0.0.2.tar.gz: pycleanarch-0.0.2/README.md <==
# PyCleanArch - Python Clean Architecture

A simple Python toolkit to work with Clean Architecture for Web. This code base is inspired by [liasis from Johnny Well](https://github.com/johnnywell/liasis/). 

Use this toolkit to build better applications implementing [Clean Architecture from Robert C. Martin](https://blog.cleancoder.com/uncle-bob/2012/08/13/the-clean-architecture.html)

## Requirements

- python3 (3.7+)
- pip3

## Install

Using **pip (pip3)**
```python
pip install pycleanarch
```

Using **pipenv**:

```python
pipenv install pycleanarch
```

Using **poetry**:

```python
poetry add pycleanarch
```

## Usage

```python
# to uuse in your project eg.:
from pycleanarch.core.domain import Entity
```

## Concepts:

DDD, Clean Architecture, TDD, Hexagonal Architecture, Onion Architecture, and much more. See some links below.

### Articles

- [The Clean Architecture by Robert C. Martin (Uncle Bob)](https://blog.cleancoder.com/uncle-bob/2012/08/13/the-clean-architecture.html)
- [The Onion Architecture by Jeffrey Palermo](https://jeffreypalermo.com/2008/07/the-onion-architecture-part-1/)
- [Hexagonal Architecture by Alistair Cockburn](https://web.archive.org/web/20180408231827/http://alistair.cockburn.us/Hexagonal+architecture)

### Books

- [Clean Architecture: A Craftsman's Guide to Software Structure and Design by Robert C. Martin (Uncle Bob)](https://amzn.to/2MFJX8O)
- [Domain-Driven Design Distilled by Vaughn Vernon ](https://amzn.to/35tM74g)
- [Domain Driven Development by Eric Evans (2003)](https://amzn.to/2M8c9Cn)
- [Domain Driven Development by Eric Evans (2003) - Portuguese](https://amzn.to/2IKgnOq)

## Contributing

I encourage you to contribute to this project! Join us!

Trying to report a possible security vulnerability? [Open a issue now.](https://github.com/wallacesilva/pycleanarch/issues/new)

Everyone interacting in this project and its sub-projects' codebases, issue trackers, chat rooms, and mailing lists is expected to follow the code of conduct (building, but respect everyone).

## License

MIT License

==> pycleanarch-0.0.3.tar.gz: pycleanarch-0.0.3/README.md <==
# PyCleanArch - Python Clean Architecture

A simple Python toolkit to work with Clean Architecture for Web. This code base is inspired by [liasis from Johnny Well](https://github.com/johnnywell/liasis/). 

Use this toolkit to build better applications implementing [Clean Architecture from Robert C. Martin](https://blog.cleancoder.com/uncle-bob/2012/08/13/the-clean-architecture.html)

## Requirements

- python3 (3.7+)
- pip3

## Install

Using **pip (pip3)**

```python
pip install pycleanarch
```

Using **pipenv**:

```python
pipenv install pycleanarch
```

Using **poetry**:

```python
poetry add pycleanarch
```

## Usage

```python
# to use in your project eg.:
from pycleanarch.core.domain import Entity
```

## Concepts:

This project use some concepts like DDD, Clean Architecture, TDD, Hexagonal Architecture, Onion Architecture, and much more. See some links below.

### Articles

- [The Clean Architecture by Robert C. Martin (Uncle Bob)](https://blog.cleancoder.com/uncle-bob/2012/08/13/the-clean-architecture.html)
- [The Onion Architecture by Jeffrey Palermo](https://jeffreypalermo.com/2008/07/the-onion-architecture-part-1/)
- [Hexagonal Architecture by Alistair Cockburn](https://web.archive.org/web/20180408231827/http://alistair.cockburn.us/Hexagonal+architecture)

### Books

- [Clean Architecture: A Craftsman's Guide to Software Structure and Design by Robert C. Martin (Uncle Bob)](https://amzn.to/2MFJX8O)
- [Domain-Driven Design Distilled by Vaughn Vernon ](https://amzn.to/35tM74g)
- [Domain Driven Development by Eric Evans (2003)](https://amzn.to/2M8c9Cn)
- [Domain Driven Development by Eric Evans (2003) - Portuguese](https://amzn.to/2IKgnOq)

## Contributing

I encourage you to contribute to this project! Join us!

Trying to report a possible security vulnerability? [Open a issue now.](https://github.com/wallacesilva/pycleanarch/issues/new)

Everyone interacting in this project and its sub-projects' codebases, issue trackers, chat rooms, and mailing lists is expected to follow the code of conduct (building, but respect everyone).

## License

MIT License
